@@ -92,7 +92,8 @@ h2 = 0x98BADCFE
 h3 = 0x10325476
 
 -- | Processes a lazy ByteString and returns the md5 digest.
---   This is probably what you want.
+--   This is probably what you want. You can use 'show' to produce the standard hex
+-- representation.
 md5 :: L.ByteString -> MD5Digest
 md5 = hash
 
@@ -140,7 +141,15 @@ performMD5Update par@(MD5Par !a !b !c !d) !bs =
 {-# INLINE performMD5Update #-}
 
 isAligned :: ByteString -> Bool
+#if !MIN_VERSION_bytestring(0,11,0)
 isAligned (PS _ off _) = off `rem` 4 == 0
+#else
+isAligned = const True
+-- This is semantically equivalent to the definition above, because
+-- in bytestring-0.11 offset is always 0. Note that neither definition checks
+-- that a pointer (the first field of 'PS') is aligned. Anyways 'isAligned'
+-- is used for optimization purposes only and does not affect correctness.
+#endif
 
 applyMD5Rounds :: MD5Partial -> ByteString -> MD5Partial
 applyMD5Rounds (MD5Par a b c d) w = {-# SCC "applyMD5Rounds" #-}
@@ -259,7 +268,7 @@ getNthWord n = right . G.runGet G.getWord32le . B.drop (n * sizeOf (undefined ::
 -- | The raw bytes of an 'MD5Digest'. It is always 16 bytes long.
 --
 -- You can also use the 'Binary' or 'S.Serialize' instances to output the raw
--- bytes. Alternatively you can use 'show' to prodce the standard hex
+-- bytes. Alternatively you can use 'show' to produce the standard hex
 -- representation.
 --
 md5DigestBytes :: MD5Digest -> B.ByteString
